@@ -1,8 +1,9 @@
 from contextlib import contextmanager
 from abc import ABCMeta
+from flask import logging
 import inject
 from twisted.internet import reactor
-
+from twisted.python import log
 
 class Interface(object):
     __metaclass__ = ABCMeta
@@ -13,6 +14,17 @@ def inject_services(configurator):
     yield
     inject.clear()
 
+@contextmanager
+def injector(bind_config):
+
+    def configurator(binder):
+        for key, val in bind_config.items():
+            binder.bind(key, val)
+
+    inject.clear_and_configure(configurator)
+    yield
+    inject.clear()
+
 
 def txtimeout(deferred, timeout, fail):
     delayedCall = reactor.callLater(timeout, fail)
